﻿(function () {
    'use strict';

    var itemStatusViewComponent = {
        templateUrl: Umbraco.Sys.ServerVariables.application.applicationPath + 'App_Plugins/TranslationManager/items/itemStatusView.html',
        bindings: {
            nodeId: '<'
        },
        controllerAs: 'vm',
        controller: itemStatusViewController
    };

    function itemStatusViewController($scope,
        editorService,
        editorState,
        translateStatusService,
        translateDialogManager) {

        var vm = this;
        vm.loading = true;
        vm.versions = [];

        vm.viewJob = viewJob;
        vm.viewItem = viewItem;

        vm.createTranslation = createTranslation;
        vm.getVersionStatus = getVersionStatus;


        vm.$onInit = function () {
            getVersionStatus(vm.nodeId);
        };

        $scope.$on('translate-reloaded', function (event, args) {
            getVersionStatus(vm.nodeId);
        });

        ///////////////////////

        function getVersionStatus(id) {
            vm.loading = true;
            translateStatusService.getStatus(id)
                .then(function (result) {
                    vm.versions = result.data;
                    vm.loading = false;
                });
        }

        function viewJob(jobId, $event) {
            if ($event !== undefined) {
                $event.preventDefault();
                $event.stopPropagation();
            }

            translateDialogManager.openJob(jobId, function () {
                vm.getVersionStatus(vm.nodeId);
            });
        }

        function viewItem(itemId, $event) {
            if ($event !== undefined) {
                $event.preventDefault();
                $event.stopPropagation();
            }

            translateDialogManager.openItem(itemId, function () {
                vm.getVersionStatus(vm.nodeId);
            });
        }

        function createTranslation(version, $event) {
            if ($event !== undefined) {
                $event.preventDefault();
                $event.stopPropagation();
            }

            translateDialogManager.openCreateDialog({
                entity: {
                    id: version.ContentId,
                    name: version.LanguageName
                },
                languages: [version.LanguageName]
            });
        }
    }

    angular.module('umbraco')
        .component('translateItemStatusView', itemStatusViewComponent);

})();